@@ -64,9 +64,6 @@ class WidgetBase(object):
         self.widget_js_attributes.update(
             extra_widget_js_attributes)
 
-        if 'watch' not in self.widget_js_attributes.keys():
-            self.widget_js_attributes['watch'] = '1'
-
         if 'bootstrap' not in self.widget_js_attributes.keys():
             self.widget_js_attributes['bootstrap'] = 'normal'
 
@@ -101,6 +98,8 @@ class WidgetBase(object):
         autocomplete_name = self.autocomplete_name.lower()
         return safestring.mark_safe(render_to_string([
             'autocomplete_light/%s/widget.html' % autocomplete_name,
+            'autocomplete_light/%s/widget.html' % getattr(autocomplete_name,
+                'widget_template_name', ''),
             'autocomplete_light/widget.html',
         ], {
             'name': name,
@@ -166,6 +165,6 @@ class TextWidget(forms.TextInput, WidgetBase):
 
         if 'class' not in attrs.keys():
             attrs['class'] = ''
-        attrs['class'] += 'autocomplete-light-text-widget'
+        attrs['class'] += ' autocomplete-light-text-widget'
 
         return attrs
